#!/usr/bin/python
# -*- coding: utf-8 -*-

import re

from django.template import Context
from django.template.loader import get_template
import offline
from views import offline_view


class OfflineMiddleware(object):

    def process_request(self, request):
        if request.user.is_authenticated() and offline.is_enabled() \
            and not request.user.is_staff:
            return offline_view(request)
        elif not (hasattr(request, 'user')
                  and request.user.is_authenticated()) \
            and offline.is_enabled():
            return offline_view(request)
        return

    def process_response(self, request, response):
        if hasattr(request, 'user') and offline.is_enabled() \
            and request.user.is_staff \
            and self.is_html_response(response):
            template = get_template('admin_notification.html')
            warning_message = template.render(Context())
            response.content = re.sub(r'<body.*>', '\g<0>'
                    + warning_message, response.content.decode('utf-8'))
        return response

    def is_html_response(self, response):
        return response['Content-Type'].startswith('text/html')



			



from django.db import models
from django.utils.translation import ugettext as _

class Config(models.Model):
    key = models.CharField(_('Key'), max_length=100, unique=True)
    value = models.BooleanField(_('Value'))
    message = models.TextField(_('Message'))

    def __unicode__(self):
      return self.key



from django.http import HttpResponse
from django.template import loader
from models import Config

def offline_view(request):
    offline_message = Config.objects.get(key='offline').message
    context = {
			'message':offline_message
    }
    return HttpResponse(loader.render_to_string('offline.html', context), status=503)



from models import Config


def is_enabled():
  try:
    return Config.objects.get(key='offline').value
  except Config.DoesNotExist:
    set_defaults()


def set_defaults():
  option = Config.objects.create(
      key= 'offline', 
      value= False,
      message= 'The site is under maintenance. Please come back soon.'
      )
  return option.value



import os
from setuptools import setup

README = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-offline',
    version='0.1',
    packages=['offline'],
    include_package_data=True,
    license='BSD License',  
    description='A simple Django app to swith your Django project between offline/online mode and display a 503 error page, while your django site is offline (under maintenance)',
    long_description=README,
    url='https://github.com/ankitjaiswal07/django-offline',
    author='Ankit Jaiswal',
    author_email='ankit.jaiswal07@gmail.com',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
